@@ -23,6 +23,15 @@
 #'     modifying the \code{group.size} input to the desired number of bins
 #'   \item \code{'G2'} : McKinley & Mills (1985) G2 statistic (similar method to Q1,
 #'     but with the likelihood-ratio test).
+#'   \item \code{'PV_Q1'} : Chalmers and Ng's (forthcoming) plausible-value variant
+#'     of the Q1 statistic.
+#'   \item \code{'PV_Q1*'} : Chalmers and Ng's (forthcoming) plausible-value variant
+#'     of the Q1 statistic that uses parametric boostrapping to obtain a suitable empirical
+#'     distribution.
+#'   \item \code{'X2*'} : Stone's (2000) fit statistics that require parametric
+#'     bootstrapping
+#'   \item \code{'X2*_df'} : Stone's (2000) fit statistics that require parametric
+#'     bootstrapping to obtain scaled versions of the X2* and degrees of freedom
 #'   \item \code{'infit'} : (Unidimensional Rasch model only) compute the
 #'     infit and outfit statistics. Ignored if models are not from the Rasch family
 #' }
@@ -61,11 +70,16 @@
 #'   empirical estimates. If supplied, arguments typically passed to \code{fscores()} will be
 #'   ignored and these values will be used instead. Also required when estimating statistics
 #'   with missing data via imputation
+#' @param pv_draws number of plausible-value draws to obtain for PV_Q1 and PV_Q1*
+#' @param boot number of parametric bootstrap samples to create for PV_Q1* and X2*
+#' @param boot_dfapprox number of parametric bootstrap samples to create for the X2*_df statistic
+#'   to approximate the scaling factor for X2* as well as the scaled degrees of freedom estimates
+#' @param ETrange rangone of integration nodes for Stone's X2* statistic
+#' @param ETpoints number of integration nodes to use for Stone's X2* statistic
 #' @param impute a number indicating how many imputations to perform (passed to
 #'   \code{\link{imputeMissing}}) when there are missing data present.
 #'   Will return a data.frame object with the mean estimates
 #'   of the stats and their imputed standard deviations
-#' @param digits number of digits to round result to. Default is 4
 #' @param par.strip.text plotting argument passed to \code{\link{lattice}}
 #' @param par.settings plotting argument passed to \code{\link{lattice}}
 #' @param ... additional arguments to be passed to \code{fscores()} and \code{\link{lattice}}
@@ -81,6 +95,9 @@
 #' Bock, R. D. (1972). Estimating item parameters and latent ability when responses are scored
 #' in two or more nominal categories. Psychometrika, 37, 29-51.
 #'
+#' Chalmers, R. P. & Ng, V. (forthcoming). Plausible-Value Imputation Statistics for Detecting
+#' Item Misfit. \emph{Applied Psychological Measurement}.
+#'
 #' Drasgow, F., Levine, M. V., & Williams, E. A. (1985). Appropriateness measurement with
 #' polychotomous item response models and standardized indices.
 #' \emph{British Journal of Mathematical and Statistical Psychology, 38}, 67-86.
@@ -97,6 +114,9 @@
 #' Reise, S. P. (1990). A comparison of item- and person-fit methods of assessing model-data fit
 #' in IRT. \emph{Applied Psychological Measurement, 14}, 127-137.
 #'
+#' Stone, C. A. (2000). Monte Carlo Based Null Distribution for an Alternative Goodness-of-Fit
+#' Test Statistics in IRT Models. \emph{Journal of Educational Measurement, 37}, 58-75.
+#'
 #' Wright B. D. & Masters, G. N. (1982). \emph{Rating scale analysis}. MESA Press.
 #'
 #' Yen, W. M. (1981). Using simulation results to choose a latent trait model.
@@ -131,6 +151,14 @@
 #' itemfit(x, group.bins=15, empirical.plot = 1) #empirical item plot with 15 points
 #' itemfit(x, group.bins=15, empirical.plot = 21)
 #'
+#' # PV and X2* statistics (parametric bootstrap stats not run to save time)
+#' itemfit(x, 'PV_Q1')
+#'
+#' # mirtCluster() # improve speed of bootstrap samples by running in parallel
+#' # itemfit(x, 'PV_Q1*')
+#' # itemfit(x, 'X2*') # Stone's 1993 statistic
+#' # itemfit(x, 'X2*_df') # Stone's 2000 scaled statistic with df estimate
+#'
 #' #empirical tables
 #' itemfit(x, empirical.table=1)
 #' itemfit(x, empirical.table=21)
@@ -187,7 +215,7 @@
 #' raschfit2 <- mirt(data2, 1, itemtype = 'Rasch', pars=mod2values(raschfit), TOL=NaN)
 #' itemfit(raschfit2, 'infit')
 #'
-#' # note that X2 and G2 do not require complete datasets
+#' # note that X2, G2, PV-Q1, and X2* do not require complete datasets
 #' itemfit(raschfit, c('X2', 'G2'))
 #' itemfit(raschfit, empirical.plot=1)
 #' itemfit(raschfit, empirical.table=1)
@@ -197,8 +225,10 @@
 itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nitems'),
                     group.bins = 10, group.size = NA, group.fun = mean,
                     mincell = 1, mincell.X2 = 2, S_X2.tables = FALSE,
+                    pv_draws = 30, boot = 1000, boot_dfapprox = 200,
+                    ETrange = c(-2,2), ETpoints = 11,
                     empirical.plot = NULL, empirical.CI = .95, empirical.table = NULL,
-                    method = 'EAP', Theta = NULL, impute = 0, digits = 4,
+                    method = 'EAP', Theta = NULL, impute = 0,
                     par.strip.text = list(cex = 0.7),
                     par.settings = list(strip.background = list(col = '#9ECAE1'),
                                         strip.border = list(col = "black")), ...){
@@ -210,7 +240,125 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
                        technical=list(customK=obj@Data$K, message=FALSE, warn=FALSE))
         tmpobj@Data <- tmpmod@Data
         whc <- 1L:length(Theta)
-        return(itemfit(tmpobj, Theta=Theta[[sample(whc[-ind], 1L)]], digits = Inf, ...))
+        return(itemfit(tmpobj, Theta=Theta[[sample(whc[-ind], 1L)]], ...))
+    }
+    PV_itemfit <- function(mod, which.items = 1:extract.mirt(mod, 'nitems'),
+                           draws = 100, ...){
+        pv <- fscores(mod, plausible.draws = draws, ...)
+        draws <- length(pv)
+        df.X2 <- Q1 <- matrix(NA, length(which.items), draws)
+        for (i in 1L:draws) {
+            tmp <- itemfit(mod, fit_stats='X2', which.items=which.items,
+                           Theta = pv[[i]], ...)
+            Q1[,i] <- tmp$X2
+            df.X2[,i] <- tmp$df.X2
+        }
+        Q1_m <- rowMeans(Q1)
+        df.X2_m <- rowMeans(df.X2)
+        p.Q1 <- pchisq(Q1_m, df.X2_m, lower.tail = FALSE)
+        ret <- data.frame(PV_Q1=Q1_m, df.PV_Q1=df.X2_m, p.PV_Q1=p.Q1)
+        ret
+    }
+    boot_PV <- function(mod, org, which.items = 1:extract.mirt(mod, 'nitems'),
+                        boot = 1000, draws = 30, verbose = FALSE, ...){
+        pb_fun <- function(ind, mod, N, sv, which.items, draws, ...){
+            count <- 0L
+            while(TRUE){
+                count <- count + 1L
+                if(count == 20)
+                    stop('20 consecutive parametric bootstraps failed for PV_Q1*', call.=FALSE)
+                dat <- simdata(model=mod, N=N)
+                mod2 <- mirt(dat, model, verbose=FALSE, pars=sv, technical=list(warn=FALSE))
+                if(!extract.mirt(mod2, 'converged')) next
+                tmp <- PV_itemfit(mod2, which.items=which.items, draws=draws, ...)
+                ret <- tmp$p.PV_Q1
+                if(any(is.nan(ret) | is.na(ret))) next
+                break
+            }
+            ret
+        }
+        N <- nrow(extract.mirt(mod, 'data'))
+        retQ1 <- matrix(NA, boot, length(which.items))
+        stopifnot(nrow(org) == length(which.items))
+        model <- extract.mirt(mod, 'model')
+        sv <- mod2values(mod)
+        retQ1 <- mySapply(1L:boot, pb_fun, mod=mod, N=N, sv=sv,
+                          which.items=which.items, draws=draws, ...)
+        if(nrow(retQ1) == 1L) retQ1 <- t(retQ1)
+        Q1 <- (1 + rowSums(org$p.PV_Q1 > t(retQ1), na.rm = TRUE)) / (1 + boot)
+        ret <- data.frame("p.PV_Q1_star"=Q1)
+        ret
+    }
+    StoneFit <- function(mod, which.items = 1:extract.mirt(mod, 'nitems'),
+                         dfapprox = FALSE, boot = 1000, ETrange = c(-2,2), ETpoints = 11,
+                         verbose = FALSE, ...){
+        X2star <- function(mod, which.items, ETrange, ETpoints, ...){
+            sv <- mod2values(mod)
+            sv$est <- FALSE
+            Theta <- matrix(seq(ETrange[1L], ETrange[2L], length.out=ETpoints))
+            dat <- extract.mirt(mod, 'data')
+            Emod <- mirt(dat, 1, pars=sv, verbose=FALSE,
+                         technical=list(storeEtable=TRUE, customTheta=Theta))
+            Etable <- Emod@Internals$Etable[[1]]$r1
+            itemloc <- extract.mirt(mod, 'itemloc')
+            X2 <- rep(NA, ncol(dat))
+            for(i in 1L:length(which.items)){
+                pick <- itemloc[which.items[i]]:(itemloc[which.items[i]+1L] - 1L)
+                O <- Etable[ ,pick]
+                item <- extract.item(mod, which.items[i])
+                E <- probtrace(item, Theta) * rowSums(O)
+                X2[which.items[i]] <- sum((O - E)^2 / E, na.rm = TRUE)
+            }
+            X2[which.items]
+        }
+        pb_fun <- function(ind, mod, N, model, itemtype, sv, which.items, ETrange,
+                           ETpoints, ...){
+            count <- 0L
+            while(TRUE){
+                count <- count + 1L
+                if(count == 20)
+                    stop('20 consecutive parametric bootstraps failed for X2*', call.=FALSE)
+                dat <- simdata(model=mod, N=N)
+                mod2 <- mirt(dat, model, itemtype=itemtype, verbose=FALSE, pars=sv,
+                             technical=list(warn=FALSE))
+                if(!extract.mirt(mod2, 'converged')) next
+                ret <- X2star(mod2, which.items=which.items, ETrange=ETrange,
+                              ETpoints=ETpoints, ...)
+                if(any(is.nan(ret) | is.na(ret))) next
+                break
+            }
+            ret
+        }
+
+        N <- nrow(extract.mirt(mod, 'data'))
+        X2bs <- matrix(NA, boot, length(which.items))
+        org <- X2star(mod, which.items=which.items,
+                      ETrange=ETrange, ETpoints=ETpoints, ...)
+        stopifnot(length(org) == length(which.items))
+        sv <- mod2values(mod)
+        model <- extract.mirt(mod, 'model')
+        itemtype <- extract.mirt(mod, 'itemtype')
+        X2bs <- mySapply(1L:boot, pb_fun, mod=mod, N=N, model=model,
+                         itemtype=itemtype, sv=sv, which.items=which.items,
+                         ETrange=ETrange, ETpoints=ETpoints, ...)
+        if(nrow(X2bs) == 1L) X2bs <- t(X2bs)
+        if(dfapprox){
+            M <- colMeans(X2bs)
+            V <- apply(X2bs, 2, var)
+            upsilon <- 2 * M^2 / V
+            gamma <- M / upsilon
+            df <- upsilon
+            for(i in 1L:length(which.items)){
+                item <- extract.item(mod, which.items[i])
+                df[i] <- upsilon[i] - sum(item@est)
+            }
+            ret <- data.frame(X2_star_scaled=org/gamma, df.X2_star_scaled=df,
+                              p.X2_star_scaled=pchisq(org/gamma, df, lower.tail=FALSE))
+        } else {
+            p <- apply(t(X2bs) > org, 1, mean)
+            ret <- data.frame(X2_star=org, p.X2_star=p)
+        }
+        ret
     }
 
     if(missing(x)) missingMsg('x')
@@ -218,8 +366,10 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         stop('MixedClass objects are not supported', call.=FALSE)
     if(!is.null(empirical.plot) && !is.null(empirical.table))
         stop('Please select empirical.plot or empirical.table, not both', call.=FALSE)
-    if(!all(fit_stats %in% c('S_X2', 'Zh', 'X2', 'G2', 'infit')))
+    if(!all(fit_stats %in% c('S_X2', 'Zh', 'X2', 'G2', 'infit', 'PV_Q1', 'PV_Q1*', 'X2*', 'X2*_df')))
         stop('Unsupported fit_stats element requested', call.=FALSE)
+    if(any(c('X2', 'G2', 'PV_Q1', 'PV_Q1*') %in% fit_stats) && extract.mirt(x, 'nfact') > 1L)
+        stop('X2, G2, PV_Q1, or PV_Q1* are for unidimensional models only', call.=FALSE)
     S_X2 <- 'S_X2' %in% fit_stats
     Zh <- 'Zh' %in% fit_stats
     X2 <- 'X2' %in% fit_stats
@@ -264,7 +414,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
                                 S_X2.tables=S_X2.tables, empirical.plot=empirical.plot,
                                 empirical.table=empirical.table,
                                 Theta=tmpTheta, empirical.CI=empirical.CI, method=method,
-                                impute=impute, discrete=discrete, digits=digits, ...)
+                                impute=impute, discrete=discrete, ...)
         }
         names(ret) <- x@Data$groupNames
         if(extract.mirt(x, 'ngroups') == 1L) return(ret[[1L]])
@@ -305,7 +455,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         SD$item <- paste0('SD_', SD$item)
         SD <- rbind(NA, SD)
         ret <- rbind(ave, SD)
-        ret[,sapply(ret, class) == 'numeric'] <- round(ret[,sapply(ret, class) == 'numeric'], digits)
+        class(ret) <- c('mirt_df', 'data.frame')
         return(ret)
     }
     if(S_X2.tables || discrete) Zh <- X2 <- FALSE
@@ -471,8 +621,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
                 }
             }
             if(!is.null(empirical.table)){
-                Etable <- lapply(Etable, round, digits=digits)
-                names(Etable) <- paste0('theta = ', round(mtheta_nms, digits))
+                names(Etable) <- paste0('theta = ', round(mtheta_nms, 4))
                 return(Etable)
             }
             df.X2[i] <- df.X2[i] - sum(pars[[i]]@est)
@@ -529,14 +678,14 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         if(X2){
             ret$X2 <- X2.value[which.items]
             ret$df.X2 <- df.X2[which.items]
-            ret$p.X2 <- 1 - suppressWarnings(pchisq(ret$X2, ret$df.X2))
+            ret$p.X2 <- suppressWarnings(pchisq(ret$X2, ret$df.X2, lower.tail=FALSE))
             ret$df.X2[ret$df.X2 <= 0] <- 0
             ret$p.X2[ret$df.X2 <= 0] <- NaN
         }
         if(G2){
             ret$G2 <- G2.value[which.items]
             ret$df.G2 <- df.G2[which.items]
-            ret$p.G2 <- 1 - suppressWarnings(pchisq(ret$G2, ret$df.G2))
+            ret$p.G2 <- suppressWarnings(pchisq(ret$G2, ret$df.G2, lower.tail=FALSE))
             ret$df.G2[ret$df.G2 <= 0] <- 0
             ret$p.G2[ret$df.G2 <= 0] <- NaN
         }
@@ -576,10 +725,28 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         df.S_X2 <- df.S_X2 - sum(pars[[J+1L]]@est)
         df.S_X2[df.S_X2 < 0] <- 0
         S_X2[df.S_X2 == 0] <- NaN
-        ret$S_X2 <- S_X2
-        ret$df.S_X2 <- df.S_X2
-        ret$p.S_X2 <- 1 - suppressWarnings(pchisq(ret$S_X2, ret$df.S_X2))
+        ret$S_X2 <- S_X2[which.items]
+        ret$df.S_X2 <- df.S_X2[which.items]
+        ret$p.S_X2 <- suppressWarnings(pchisq(ret$S_X2, ret$df.S_X2, lower.tail=FALSE))
     }
-    ret[,sapply(ret, class) == 'numeric'] <- round(ret[,sapply(ret, class) == 'numeric'], digits)
+    if(any(c('PV_Q1', 'PV_Q1*') %in% fit_stats)){
+        tmp <- PV_itemfit(x, which.items=which.items, draws=pv_draws, ...)
+        ret <- cbind(ret, tmp)
+    }
+    if('PV_Q1*' %in% fit_stats){
+        tmp <- boot_PV(x, org=tmp, which.items=which.items, boot=boot, draws=pv_draws, ...)
+        ret <- cbind(ret, tmp)
+    }
+    if('X2*' %in% fit_stats){
+        tmp <- StoneFit(x, which.items=which.items, boot=boot, dfapprox=FALSE,
+                 ETrange=ETrange, ETpoints=ETpoints, ...)
+        ret <- cbind(ret, tmp)
+    }
+    if('X2*_df' %in% fit_stats){
+        tmp <- StoneFit(x, which.items=which.items, boot=boot_dfapprox, dfapprox=TRUE,
+                        ETrange=ETrange, ETpoints=ETpoints, ...)
+        ret <- cbind(ret, tmp)
+    }
+    class(ret) <- c('mirt_df', 'data.frame')
     return(ret)
 }
